.. meta::
   :description: Tutorials for getting started with Hydra and hydra-zen.

.. _tutorials:

Tutorials
=========

These tutorials will acquaint you with all of the essential functionality of hydra-zen 
and Hydra. They require no prior experience with these tools. Our tutorials guide you 
with explicit, concrete steps through the process of creating and launching a Python 
application that is configurable, reproducible, and scalable.

.. note::

   These tutorials focus solely on practical steps towards concrete 
   outcomes, and thus they do not explain *how* Hydra and hydra-zen work. To gain a 
   deeper understanding of the technical details here, please refer to the 
   :ref:`hydra-zen-reference` section of our documentation. Each page includes extensive
   examples and explanations.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   tutorials/basic_app
   tutorials/add_cli
   tutorials/hierarchy
   tutorials/config_groups
   tutorials/inject_wrapper


.. tip::

   Did you enjoy these tutorials? Consider ⭐ `giving us a start on GitHub <https://github.com/mit-ll-responsible-ai/hydra-zen>`_ ⭐ to help others find this project.
